@@ -1,4 +1,13 @@
 # -*- coding: utf8 -*-
+"""
+    kaptan.handlers.file_handler
+    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+    :copyright: (c) 2013 by the authors and contributors (See AUTHORS file).
+    :license: BSD, see LICENSE for more details.
+"""
+
+from __future__ import print_function, unicode_literals
 
 from . import BaseHandler
 
