@@ -19,5 +19,8 @@ class YamlHandler(BaseHandler):
     def load(self, data):
         return yaml.load(data)
 
-    def dump(self, data, **kwargs):
-        return yaml.dump(data, **kwargs)
+    def dump(self, data, safe=False, **kwargs):
+        if not safe:
+            return yaml.dump(data, **kwargs)
+        else:
+            return yaml.safe_dump(data, **kwargs)
